@@ -108,7 +108,11 @@ def download(folder, latlim, lonlim, timelim, product_name, req_vars,
     folder = os.path.join(folder, "MERRA2")
     fn = os.path.join(folder, f"{product_name}.nc")
     if os.path.isfile(fn):
-        return open_ds(fn, "all")
+        ds = open_ds(fn)
+        if np.all([x in ds.data_vars for x in req_vars]):
+            return ds
+        else:
+            ds = ds.close()
 
     spatial_buffer = True
     if spatial_buffer:
