@@ -5,6 +5,7 @@ import pandas as pd
 import pywapor.collect.accounts as accounts
 from pywapor.general.logger import log
 import re
+import warnings
 from functools import partial
 import requests
 from pywapor.collect.protocol.crawler import download_urls, crawl
@@ -23,7 +24,11 @@ def download(folder, latlim, lonlim, timelim, product_name, req_vars = ["ndvi",
 
     fn = os.path.join(folder, f"{product_name}.nc")
     if os.path.isfile(fn):
-        return open_ds(fn, "all")
+        ds = open_ds(fn)
+        if np.all([x in ds.data_vars for x in req_vars]):
+            return ds
+        else:
+            ds = ds.close()
 
     dates = pd.date_range(timelim[0], timelim[1], freq="D")
 
@@ -66,10 +71,11 @@ def download(folder, latlim, lonlim, timelim, product_name, req_vars = ["ndvi",
     # Merge tiles.
     dss0 = list()
     for date, datasets in dss.items():
-        log.info(f"--> Merging {len(datasets)} tiles for {date.strftime('%Y-%m-%d')}.")
         bb = (lonlim[0], latlim[0], lonlim[1], latlim[1])
         ds = rioxarray.merge.merge_datasets(datasets)
-        ds = ds.rio.clip_box(*bb) # NOTE using this seperately, because `bounds`-kw for `merge_datasets` bugs.
+        with warnings.catch_warnings():
+            warnings.filterwarnings("ignore", category = FutureWarning)
+            ds = ds.rio.clip_box(*bb) # NOTE using this seperately, because `bounds`-kw for `merge_datasets` bugs.
         dss0.append(ds)
 
     # Merge dates.
@@ -85,7 +91,7 @@ def download(folder, latlim, lonlim, timelim, product_name, req_vars = ["ndvi",
 
     ds = ds[req_vars]
 
-    ds = save_ds(ds, os.path.join(folder, f"{product_name}.nc"), decode_coords = "all")
+    ds = save_ds(ds, os.path.join(folder, f"{product_name}.nc"), label = f"Merging files.")
 
     for fp in fps:
         os.remove(fp.replace(".HDF5", ".nc"))
@@ -98,7 +104,6 @@ def open_hdf5_groups(fp, variables, coords):
     if os.path.isfile(nc_fp):
         ds = open_ds(nc_fp, "all")
     else:
-        log.info(f"--> Converting {os.path.split(fp)[-1]} to netcdf.")
         ds = xr.open_dataset(fp, chunks = "auto")
 
         spatial_ref_name = [k for k, v in variables.items() if v[1] == "spatial_ref"][0]
@@ -115,7 +120,7 @@ def open_hdf5_groups(fp, variables, coords):
 
         ds = process_ds(ds, coords, variables)
 
-        ds = save_ds(ds, nc_fp, decode_coords = "all")
+        ds = save_ds(ds, nc_fp, label = f"Converting {os.path.split(fp)[-1]} to netcdf.")
 
     return ds
 
